@@ -1,7 +1,7 @@
 use proc_macro2::Ident;
 
 #[derive(Copy, Clone, PartialEq, Debug)]
-pub enum Block<'a> {
+pub(crate) enum Block<'a> {
     AnonymousNamespace,
     Namespace(&'static str),
     UserDefinedNamespace(&'a Ident),
@@ -10,7 +10,7 @@ pub enum Block<'a> {
 }
 
 impl<'a> Block<'a> {
-    pub fn write_begin(self, out: &mut String) {
+    pub(crate) fn write_begin(self, out: &mut String) {
         if let Block::InlineNamespace(_) = self {
             out.push_str("inline ");
         }
@@ -18,7 +18,7 @@ impl<'a> Block<'a> {
         out.push_str(" {\n");
     }
 
-    pub fn write_end(self, out: &mut String) {
+    pub(crate) fn write_end(self, out: &mut String) {
         out.push_str("} // ");
         self.write_common(out);
         out.push('\n');
